@@ -14,11 +14,14 @@ _mf_stats = dict()
 def deep_reload(module, loaded=None, parent=None):
     """Deep reload of module.
 
-    Borrowed from
+    Adapted from
     http://stackoverflow.com/questions/5364050/reloading-submodules-in-ipython
     """
     if is_str(module):
-        module = modules[module]
+        if module in modules:
+            module = modules[module]
+        else:
+            return
 
     if not is_module(module):
         module = getmodule(module)
@@ -39,10 +42,9 @@ def deep_reload(module, loaded=None, parent=None):
             try:
                 m_file = module.__file__
                 m_mtime = stat(m_file).st_mtime
-                if m_mtime > _mf_stats.get(m_file, 0):
+                if m_file in _mf_stats and m_mtime > _mf_stats[m_file]:
                     reload(module)
-                    _mf_stats[m_file] = m_mtime
-                    logger.debug('reload module %s' % module)
+                _mf_stats[m_file] = m_mtime
                 loaded.add(module)
             except:
                 logger.error('reload module %s' % module, exc_info=True)
