@@ -1,3 +1,9 @@
+# modules to trigger deep autoreload
+MODULES_AUTORELOAD = set()
+
+# assert services calls via ssl/tls channel
+USE_SSL = True
+
 # user session timeout in seconds
 SESSION_TIMEOUT = 3600
 
