@@ -13,7 +13,18 @@ logger = logging.getLogger('fanery.server')
 
 
 def start_wsgi_server(wsgi_app=None, host='127.0.0.1', port=9000,
-                      bjoern=True, gevent=False, cherrypy=False, **argd):
+                      bjoern=True, gevent=False, cherrypy=False,
+                      remote_debugger=False, **argd):
+
+    if remote_debugger is True:
+        from _crypto import nacl_random, nacl_sha256
+        import rpdb2
+        rpdb2_passwd = nacl_sha256(nacl_random(16))
+        rpdb2.start_embedded_debugger(rpdb2_passwd,
+                                      fAllowRemote=True,
+                                      fAllowUnencrypted=False)
+        logger.debug("rpdb2 remote debugger started with password '%s'" % rpdb2_passwd)   # noqa
+        del rpdb2_passwd
 
     ssl = argd.pop('ssl', config.USE_SSL)
 
