@@ -10,7 +10,6 @@ from _crypto import (
     nacl_nonce, nacl_random, nacl_sha256,
     PrivateKey, PublicKey, Box, SigningKey
 )
-from _autoreload import deep_reload
 from _auth import hooks as auth
 from _state import get_state
 import _config as conf
@@ -85,10 +84,8 @@ def service(urlpath=None, auto_parse=True, static=False, accel=False,
     def decorator(f):
         srv_path = (urlpath or f.__name__).strip('/')
 
-        modules_autoreload = conf.MODULES_AUTORELOAD
-
         if srv_path in registry:
-            if force_define is True or modules_autoreload:
+            if force_define is True or conf.MODULES_AUTORELOAD:
                 logger.debug("redefine service '%s' %s" % (srv_path, f))
             else:
                 raise exc.MultipleDefine(srv_path)
@@ -96,10 +93,6 @@ def service(urlpath=None, auto_parse=True, static=False, accel=False,
         @wraps(f)
         def wrapper(*args, **argd):
 
-            if modules_autoreload:
-                for module in modules_autoreload:
-                    deep_reload(module)
-
             _state_ = get_state()
 
             if ssl is not False and (conf.USE_SSL or ssl) and not _state_.ssl:
